Cheetah.Tools.turbocheetah.cheetahsupport module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Tools.turbocheetah.cheetahsupport module

Template support for Cheetah

class `Cheetah.Tools.turbocheetah.cheetahsupport.` `TurboCheetah`(extra_vars_func=None, options=None)

  Bases: `object`

  `extension` = 'tmpl'
  `load_template`(template=None, template_string=None, template_file=None, loadingSite=False)

    Searches for a template along the Python path.

    Template files must end in ”.tmpl” and be in legitimate packages.

  `load_template_file`(filename)
  `load_template_module`(classname)
  `load_template_string`(content)
  `render`(info, format='html', fragment=False, template=None, template_string=None, template_file=None)